import 'package:base_repository/base_repository.dart';
import 'package:flutter/material.dart';
import 'impl/assets_repository_impl.dart';

///
/// VirtualRepository
/// 虚拟资产相关的网络库
///
abstract class AssetsRepository {
  static AssetsRepository get() {
    return AssetsRepositoryImpl();
  }

  ///
  /// 获取免单商品列表
  /// [page]        当前页
  /// [pagesize]    每页显示数据量大小
  /// [freeType]    1:天天免单 2:新人后返 3:直播超级返 4:拼多多免单 5:直播ysh免单，7程七直播免单   这一版只有5 和7
  ///
  Future<DSResponseList> itemFreeList({
    int page = 1,
    int pagesize = 10,
    @required int freeType,
  });

  ///
  /// 获取免单记录
  /// [page]          当前页
  /// [pagesize]      每页显示数据量大小
  ///
  Future<DSResponseList<Map<String, dynamic>>> itemFreeRecord({
    int page = 1,
    int pagesize = 10,
  });

  ///
  /// 收益明细列表
  /// [page]          当前页
  /// [pagesize]      每页显示数据量大小
  /// [source]        来源 1全部，2我的订单，3团队订单
  /// [type]          类型 0全部 1人民币，2积分，3免单点
  ///
  Future<DSResponseList> qryBillRecord({
    int page = 1,
    int pagesize = 10,
    int source = 1,
    int type = 0,
  });

  ///
  /// 收益明细详情
  /// [id]            数据id
  ///
  Future<DSResponseObject> qryBillRecordDetail({
    @required String id,
  });

  ///
  /// 积分兑换
  /// [type]           选中积分的类型
  /// [value]          输入的自定义值
  ///
  Future<DSResponseObject> scoreExchange({
    @required String type,
    String value,
  });

  ///
  /// 获取虚拟资产任务列表
  ///
  Future<DSResponseList> getVirtualTask();

  ///
  /// 领取任务奖励接口
  /// [id]             任务Id
  ///
  Future<DSResponseObject> receiveTaskAward({@required String id});

  ///
  /// 获取广告位id
  /// [type]          系统: 1、Android  2、iOS
  /// [category]      1:激励视频广告 ,2:插屏广告,3:开屏广告 ,4:Banner广告,5.信息流广告,6.全屏广告,7.信息流广告
  ///
  Future<DSResponseList<Map<String, dynamic>>> videoAdGetSite({@required int type,@required int category});


  ///
  /// 观看视频的积分兑换
  ///
  Future<DSResponseObject> videoScoreConvert();
}
