import 'package:base_repository/base_repository.dart';
import 'package:flutter/material.dart';
import '../assets_repository.dart';

class AssetsRepositoryImpl extends AssetsRepository {
  AssetsRepositoryImpl.get();
  static final AssetsRepositoryImpl _instance = AssetsRepositoryImpl.get();
  factory AssetsRepositoryImpl() {
    return _instance;
  }

  @override
  Future<DSResponseList> itemFreeList({
    int page = 1,
    int pagesize = 10,
    @required int freeType,
  }) async {
    dynamic result = await DSDioUtil.getInstance().get(
      '/itemFree.getItemList',
      queryParameters: {
        'page': page,
        'pagesize': pagesize,
        'free_type': freeType,
      },
    );
    return DSResponseList.fromJson(
      result,
      (item){
        String productId = "${item['id']}";
        Map<String,dynamic> idata = Map<String, dynamic>.from(item);
        idata['product_id'] = productId;
        return idata;
      },
    );
  }

  @override
  Future<DSResponseList> getVirtualTask() async {
    dynamic result = await DSDioUtil.getInstance().get('/sign.getTask');
    return DSResponseList.fromJson(
      result,
      (item) => Map<String, dynamic>.from(item),
    );
  }

  @override
  Future<DSResponseList> qryBillRecord({
    int page = 1,
    int pagesize = 10,
    int source = 1,
    int type = 0,
  }) async {
    dynamic result = await DSDioUtil.getInstance().get(
      '/billRecord.list',
      queryParameters: {
        'page': page,
        'pagesize': pagesize,
        'source': source,
        'type': type,
      },
    );
    return DSResponseList.fromJson(
      result,
      (item) => Map<String, dynamic>.from(item),
    );
  }

  @override
  Future<DSResponseObject> qryBillRecordDetail({String id}) async {
    dynamic result = await DSDioUtil.getInstance()
        .get('/billRecord.detail', queryParameters: {'id': id});
    return DSResponseObject.fromJson(
      result,
      (item) => Map<String, dynamic>.from(item),
    );
  }

  @override
  Future<DSResponseObject> receiveTaskAward({String id}) async {
    dynamic result =
        await DSDioUtil.getInstance().post('/sign.distributeReward',data:{'id':id});
    return DSResponseObject.fromJson(
      result,
      (item) => Map<String, dynamic>.from(item),
    );
  }

  @override
  Future<DSResponseObject> scoreExchange({@required String type, String value}) async {
    Map<String,dynamic> data = {};
    if(type != null){
      data['type'] = type;
    }
    if(value != null){
      data['value'] = value;
    }
    dynamic result = await DSDioUtil.getInstance().post('/sign.scoreExchange',data:data);
    return DSResponseObject.fromJson(
      result,
      (item) => Map<String, dynamic>.from(item),
    );
  }

  @override
  Future<DSResponseList<Map<String, dynamic>>> itemFreeRecord(
      {int page = 1, int pagesize = 10}) async {
    dynamic result = await DSDioUtil.getInstance().get('/itemFree.getRecord');
    return DSResponseList.fromJson(
      result,
      (item) => Map<String, dynamic>.from(item),
    );
  }

  ///
  /// 获取广告位id
  /// [type]          系统: 1、Android  2、iOS
  /// [category]      1:激励视频广告 ,2:插屏广告,3:开屏广告 ,4:Banner广告,5.信息流广告,6.全屏广告,7.信息流广告
  ///
  @override
  Future<DSResponseList<Map<String, dynamic>>> videoAdGetSite({int type, int category}) async{
    dynamic result = await DSDioUtil.getInstance().get('/video.getSite',queryParameters:{'type':type,'category':category});
    return DSResponseList.fromJson(
      result,
      (item) => Map<String, dynamic>.from(item),
    );
  }

  @override
  Future<DSResponseObject> videoScoreConvert() async{
    dynamic result = await DSDioUtil.getInstance().post('/video.convert');
    return DSResponseObject.fromJson(
      result,
      (data) => Map<String, dynamic>.from(data),
    );
  }
}
