import 'package:flutter/foundation.dart';
import 'package:base_repository/base_repository.dart';
import 'package:xiaoxiong_repository/entity/product_details_entity.dart';
import 'package:xiaoxiong_repository/entity/product_item_entity.dart';
import 'package:xiaoxiong_repository/entity/turn_chain_entity.dart';
import 'impl/price_repository_impl.dart';

///
/// PriceRepository
/// 好价相关的网络库
///
abstract class PriceRepository {
  static PriceRepository get() {
    return PriceRepositoryImpl();
  }

  ///
  /// 好价商品列表
  /// [POST]                  itemSelling.getList
  /// [page]                  查询的页码
  /// [pagesize]              查询每页的长度
  /// [keywords]              搜索的关键词
  /// [categoryId]            快捷分类id
  /// [excludeId]             需要排除的Id
  /// [filters]               搜索的条件
  ///
  Future<DSResponseList<ProductItemEntity>> qryProductList(
      {int page = 1,
      int pagesize = 10,
      String keywords,
      String categoryId,
      String excludeId,
      List<dynamic> filters});

  ///
  /// 获取商品详情
  /// [id]                  商品详情Id
  ///
  Future<DSResponseObject<ProductDetailsEntity>> qryProductDetails(
      {@required String id});

  ///
  /// 好价推荐列表
  /// [keywords]            搜索关键词
  /// [excludeId]          排除id
  /// [page]                  当前页码
  /// [pagesize]              当前页显示的大小
  ///
  Future<DSResponseList<ProductItemEntity>> getSellingRecommends({
    String keywords,
    String excludeId,
    int page = 1,
    int pagesize = 10,
  });

  ///
  /// 优惠举报
  /// [id]                  数据库Id
  /// [reportType]          举报类型
  ///
  Future<DSResponseBool> report(
      {@required String id, @required String reportType});

  ///
  /// 点赞
  /// [mark_id]                 商品id
  /// [type]                    点赞类型， 1普通商品 2好价商品
  /// [status]                  点赞状态1点赞 2取消点赞
  /// [platform]                平台 20好价
  ///
  Future<DSResponseBool> userLike(
      {@required String markId,
      String type = '2',
      String status = '1',
      String platform = '20'});

  ///
  /// 用户收藏/取消商品
  /// [itemId]                  商品id
  /// [type]                    点赞类型， 1普通商品 2好价商品
  /// [platform]                平台类型
  /// [status]                  点赞状态1点赞 2取消点赞
  ///
  Future<DSResponseBool> userCollect(
      {@required String itemId,
      String type = '2',
      String platform = '20',
      String status = '1'});

  ///
  /// 通过商品Id进行转链
  /// [itemId]                  商品id
  /// [platform]                平台，1淘宝 2京东 3拼多多 4唯品会
  /// [type]                    转链类型  好价传6   默认为5
  ///
  Future<DSResponseObject<TurnChainEntity>> turnChainForItemId(
      {@required String itemId,
      @required String platform,
      String type = '5',
      String sellerId = ''});
}
